/* -*- Mode: C; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/*
 *  Copyright (C) 2011 Theppitak Karoonboonyanan <theppitak@gmail.com>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2, or (at your option)
 *  any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
 */

#ifndef __ENGINE_CONST_H__
#define __ENGINE_CONST_H__

#define CONFIG_SCHEMA     "org.freedesktop.ibus.libthai"

#define CONFIG_KB_LAYOUT  "kb-layout"
#define CONFIG_ISC_MODE   "isc-mode"
#define CONFIG_DO_CORRECT "do-correct"


#endif /* __ENGINE_CONST_H__ */

/*
vi:ts=2:nowrap:ai:expandtab
*/
